==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: ""

, "summary"
: ""

, "Total Timesheets"
: ""

, "Billable Timesheets"
: ""

, "Total Time"
: ""

, "Time of Billable Timesheets"
: ""

, "Description"
: "Kuvaus"

, "Detail"
: ""

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: ""

, "Export as CSV"
: ""

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Aikataulu"
 ,"Aikataulut"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Sopimus"

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Yksikkö"

, "Unit Price"
: "Yksikkö hinta"

, "Factor"
: ""

, "Budget"
: "Budjetti"

, "Status"
: "Tila"

, "closed"
: "suljettu"

, "open"
: "avoin"

, "Cleared In"
: ""

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: ""

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  ""
 ,""

]
, "Number"
: "Numero"

, "Title"
: "Otsikko"

, "Access"
: ""

, "Permissions"
: ""

, "Time Account - Billed"
: ""

, "not yet billed"
: "ei vielä maksettu"

, "to bill"
: ""

, "billed"
: ""

, "Time Account - Status"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: ""

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Näytä kaikki"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: ""

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: ""

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: ""

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "oletus"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: "edellinen viikko"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: ""

, "Billed"
: "Maksettu"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Käyttäjätili"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Laskutettava"

, "Cleared"
: "Selvitetty"

, "Date"
: "Päivä"

, "Start time"
: ""

, "End time"
: ""

, "Duration"
: ""

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: ""

, "Timetracker"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: "Hallitse aikatauluja"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Lisää, muokkaa tai poista aikatauluja"

, "Add timeaccounts"
: "Lisää aikataulu"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""


, "Timesheet"
: "Aikataulu"

, "Timeaccount"
: ""

, "Time Account"
: ""

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: ""

, "summary"
: ""

, "Total Timesheets"
: ""

, "Billable Timesheets"
: ""

, "Total Time"
: ""

, "Time of Billable Timesheets"
: ""

, "Description"
: "Kuvaus"

, "Detail"
: ""

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: ""

, "Export as CSV"
: ""

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Aikataulu"
 ,"Aikataulut"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Sopimus"

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Yksikkö"

, "Unit Price"
: "Yksikkö hinta"

, "Factor"
: ""

, "Budget"
: "Budjetti"

, "Status"
: "Tila"

, "closed"
: "suljettu"

, "open"
: "avoin"

, "Cleared In"
: ""

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: ""

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  ""
 ,""

]
, "Number"
: "Numero"

, "Title"
: "Otsikko"

, "Access"
: ""

, "Permissions"
: ""

, "Time Account - Billed"
: ""

, "not yet billed"
: "ei vielä maksettu"

, "to bill"
: ""

, "billed"
: ""

, "Time Account - Status"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: ""

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Näytä kaikki"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: ""

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: ""

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: ""

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "oletus"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: "edellinen viikko"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: ""

, "Billed"
: "Maksettu"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: ""

, "Account"
: "Käyttäjätili"

, "Time Account (Number - Title)"
: ""

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "Laskutettava"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "Päivä"

, "Start time"
: ""

, "End time"
: ""

, "Duration"
: ""

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Manage timeaccounts"
: "Hallitse aikatauluja"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Lisää, muokkaa tai poista aikatauluja"

, "Add timeaccounts"
: "Lisää aikataulu"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""



, "Timesheet"
: "Aikataulu"

, "Timeaccount"
: ""

, "Time Account"
: ""

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
